#!/usr/bin/env bash
# Examples for: search

# Search for researcher agents
agentspec search researcher --registry http://localhost:3000

# JSON output
agentspec search coder --registry http://localhost:3000 --output json
